@@ -1,6 +1,4 @@
-/* © 2006-2007 Anselm R. Garbe <garbeam at gmail dot com>
- * © 2006-2007 Sander van Dijk <a dot h dot vandijk at gmail dot com>
- * See LICENSE file for license details. */
+/* See LICENSE file for copyright and license details. */
 #include "dwm.h"
 #include <stdlib.h>
 #include <string.h>
@@ -129,8 +127,8 @@ detach(Client *c) {
 
 void
 focus(Client *c) {
-	if(c && !isvisible(c))
-		return;
+	if((!c && selscreen)|| (c && !isvisible(c)))
+		for(c = stack; c && !isvisible(c); c = c->snext);
 	if(sel && sel != c) {
 		grabbuttons(sel, False);
 		XSetWindowBorder(dpy, sel->win, dc.norm[ColBorder]);
@@ -152,14 +150,6 @@ focus(Client *c) {
 		XSetInputFocus(dpy, root, RevertToPointerRoot, CurrentTime);
 }
 
-void
-focustopvisible(void) {
-	Client *c;
-
-	for(c = stack; c && !isvisible(c); c = c->snext);
-	focus(c);
-}
-
 void
 killclient(const char *arg) {
 	XEvent ev;
@@ -230,8 +220,7 @@ manage(Window w, XWindowAttributes *wa) {
 	XMoveWindow(dpy, w, c->x + 2 * sw, c->y);
 	XMapWindow(dpy, w);
 	setclientstate(c, NormalState);
-	if(isvisible(c))
-		focus(c);
+	focus(c);
 	lt->arrange();
 }
 
@@ -305,6 +294,8 @@ togglefloating(const char *arg) {
 	if(!sel || lt->arrange == floating)
 		return;
 	sel->isfloating = !sel->isfloating;
+	if(sel->isfloating)
+		resize(sel, sel->x, sel->y, sel->w, sel->h, True);
 	lt->arrange();
 }
 
@@ -399,7 +390,7 @@ unmanage(Client *c) {
 	detach(c);
 	detachstack(c);
 	if(sel == c)
-		focustopvisible();
+		focus(NULL);
 	XUngrabButton(dpy, AnyButton, AnyModifier, c->win);
 	setclientstate(c, WithdrawnState);
 	free(c->tags);
