@@ -1,6 +1,4 @@
-/* © 2006-2007 Anselm R. Garbe <garbeam at gmail dot com>
- * © 2006-2007 Sander van Dijk <a dot h dot vandijk at gmail dot com>
- * See LICENSE file for license details. */
+/* See LICENSE file for copyright and license details. */
 #include "dwm.h"
 #include <errno.h>
 #include <locale.h>
@@ -278,8 +276,8 @@ main(int argc, char *argv[]) {
 	fd_set rd;
 	XEvent ev;
 
-	if(argc == 2 && !strncmp("-v", argv[1], 3))
-		eprint("dwm-"VERSION", © 2004-2007 Anselm R. Garbe, Sander van Dijk\n");
+	if(argc == 2 && !strcmp("-v", argv[1]))
+		eprint("dwm-"VERSION", © 2006-2007 A. R. Garbe, S. van Dijk, J. Salmi, P. Hruby, S. Nagy\n");
 	else if(argc != 1)
 		eprint("usage: dwm [-v]\n");
 	setlocale(LC_CTYPE, "");
